package com.nosum.deliver.author.controller;

import com.nosum.common.base.domain.PageInfo;
import com.nosum.common.base.domain.Result;
import com.nosum.deliver.author.domain.po.Author;
import com.nosum.deliver.author.domain.po.AuthorVideo;
import com.nosum.deliver.author.service.AuthorService;
import com.nosum.deliver.author.service.AuthorVideoService;
import org.bson.types.ObjectId;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.UUID;

/**
 * 作者信息接口层.
 *
 * @author Young
 */
@RestController
@RequestMapping("/admin/author-video")
public class AuthorVideoAdminController {

    @Autowired
    private AuthorVideoService authorVideoService;

    @PostMapping("/save")
    public Result<Void> save(@RequestBody AuthorVideo authorVideo) {
        authorVideoService.save(authorVideo);
        return Result.createWithSuccessMessage();
    }

    @GetMapping("/{id}")
    public Result<AuthorVideo> get(@PathVariable("id") ObjectId id) {
        return Result.createWithModel(authorVideoService.getById(id));
    }


    @GetMapping("/page")
    public Result<AuthorVideo> page(AuthorVideo authorVideo) {
        PageInfo<AuthorVideo> pageInfo = authorVideoService.getPage(PageInfo.withRequest(), authorVideo);
        return Result.createWithPaging(pageInfo.getRecord(), pageInfo);
    }


    @DeleteMapping("/{id}")
    public Result<Void> remove(@PathVariable("id") ObjectId id) {
        authorVideoService.remove(id);
        return Result.createWithSuccessMessage();
    }

}
