package com.nosum.deliver.author.domain.po;


import lombok.Data;
import lombok.experimental.Accessors;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Transient;
import org.springframework.data.mongodb.core.mapping.Document;

import java.time.LocalDateTime;

/**
 * 作者信息.
 *
 * @author Young
 */
@Data
@Accessors(chain = true)
@Document(value = "author")
public class Author {

    /**
     * ID
     */
    @Id
    private ObjectId id;

    /**
     * 头像
     */
    private String avatar = "https://www.byteblogs.com/_nuxt/img/764e1e5.png";

    /**
     * 粉丝数
     */
    private Integer fansCount = 0;

    /**
     * 粉丝数搜索
     */
    @Transient
    private String fansCountStr;

    /**
     * 投放条数
     */
    private Integer putCount = 0;

    /**
     * 开始投放时间
     */
    private LocalDateTime putStartTime = LocalDateTime.now();

    /**
     * 投放量级
     */
    private Integer putLevelCount = 0;

    /**
     * 账户
     */
    private String finderUin;

    /**
     * 来源渠道
     */
    private String fromChannelName;

    /**
     * 是否有账外账号
     */
    private Integer outSideAccountFlag;

    /**
     * 等级
     */
    private String level;

    /**
     * 微信号
     */
    private String weChatAccount;

    /**
     * 视频账号
     */
    private String videoAccount = "";

    /**
     * 发布次数
     */
    private Integer sendVideoCount = 0;

    /**
     * 视频账号名称
     */
    private String videoAccountName = "";

    /**
     * 视频号简介
     */
    private String videoAccountInfo = "";

    /**
     * 分类名称
     */
    private String categoryName;

    /**
     * 拟定认证信息
     */
    private String authInfo;

    /**
     * 是否本地作者
     */
    private Integer isLocal;

    /**
     * 影响力描述
     */
    private String prove;

    /**
     * 是否下发流量
     */
    private Integer isSend;

    /**
     * 下发流量发送原因
     * 1 新入驻作者
     * 0 作者首条发文
     */
    private Integer sendReason;

    /**
     * 下发流量数量
     */
    private Integer sendCount;

    /**
     * 创建时间
     */
    private LocalDateTime createTime = LocalDateTime.now();


}
